==> spux-0.2.1-py2.py3-none-any.whl: spux/models/randomwalk.py <==
# # # # # # # # # # # # # # # # # # # # # # # # # #
# Random Walk Model class
#
# Jonas Sukys
# Eawag, Switzerland
# jonas.sukys@eawag.ch
# All rights reserved.
# # # # # # # # # # # # # # # # # # # # # # # # # #

from scipy import stats
import numpy

from spux.models.model import Model
from spux.utils.annotate import annotate

class Randomwalk (Model):
    
    # no need for sandboxing
    sandboxing = 0

    # construct model
    def __init__ (self, stepsize=1):

        self.stepsize = stepsize

    # initialize model using specified 'input' and 'parameters'
    def init (self, input, parameters):

        # base class 'init (...)' method - OPTIONAL
        Model.init (self, input, parameters)

        self.position = parameters ["origin"]
        self.trend = parameters ["trend"]
        
        self.time = 0

    # run model up to specified 'time' and return the prediction
    def run (self, time):

        # base class 'run (...)' method - OPTIONAL
        Model.run (self, time)
        
        # pre-generate random variables for all steps
        steps = time - self.time
        distribution = stats.uniform (loc=-1, scale=2)
        rvs = distribution.rvs (steps, random_state=self.rng)

        # update position (e.g, perform walk)
        directions = numpy.where (rvs < self.trend, 1, -1)
        self.position += self.stepsize * numpy.sum (directions)
        
        # update time
        self.time = time

        # return results
        return annotate ([self.position], ['position'], time)

==> spux-0.3.0-py2.py3-none-any.whl: spux/models/randomwalk.py <==
# # # # # # # # # # # # # # # # # # # # # # # # # #
# Randomwalk Model class
#
# Jonas Sukys
# Eawag, Switzerland
# jonas.sukys@eawag.ch
# All rights reserved.
# # # # # # # # # # # # # # # # # # # # # # # # # #

from scipy import stats
import numpy

from spux.models.model import Model
from spux.utils.annotate import annotate

class Randomwalk (Model):
    """Class for Randomwalk model."""

    # no need for sandboxing
    sandboxing = 0

    # construct model
    def __init__ (self, stepsize=1):

        self.stepsize = stepsize

    # initialize model using specified 'input' and 'parameters'
    def init (self, input, parameters):
        """Initialize model using specified 'input' and 'parameters'."""

        # base class 'init (...)' method - OPTIONAL
        Model.init (self, input, parameters)

        self.position = parameters ["origin"]
        self.drift = parameters ["drift"]

        self.time = 0

    # run model up to specified 'time' and return the prediction
    def run (self, time):
        """Run model up to specified 'time' and return the prediction."""

        # base class 'run (...)' method - OPTIONAL
        Model.run (self, time)

        # pre-generate random variables for all steps
        steps = time - self.time
        distribution = stats.uniform (loc=-1, scale=2)
        rvs = distribution.rvs (steps, random_state=self.rng)

        # update position (e.g., perform walk)
        directions = numpy.where (rvs < self.drift, 1, -1)
        self.position += self.stepsize * numpy.sum (directions)

        # update time
        self.time = time

        # return results
        return annotate ([self.position], ['position'], time)
